Documentation
¶
Overview ¶
Package masque implements an HTTP/3 CONNECT-UDP proxy as specified by RFC 9298. It uses the same authentication and outbound source selection as the TCP and SOCKS5 servers.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Server ¶
type Server struct {
// contains filtered or unexported fields
}
Server serves MASQUE CONNECT-UDP tunnels over HTTP/3.
func NewServer ¶
func NewServer(ctx serverbase.Context, certFile, keyFile string) (*Server, error)
NewServer builds a MASQUE server. An empty certificate pair generates and persists a self-signed pair using the same state directory as HTTPS mode.
Click to show internal directories.
Click to hide internal directories.